/*
Copyright (c) 2007, Dennis M. Sosnoski
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
 * Neither the name of JiBX nor the names of its contributors may be used
   to endorse or promote products derived from this software without specific
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package org.jibx.schema.codegen.datamodel;

import java.util.Iterator;
import java.util.List;

import org.jibx.schema.INamed;
import org.jibx.schema.SchemaTestBase;
import org.jibx.schema.elements.AnnotatedBase;
import org.jibx.schema.elements.SchemaElement;

/**
 * TODO
 */
public class ModelBuilderTest extends SchemaTestBase
{
    public static final String COMPLEX_EMPTY_SCHEMA =
        "<schema targetNamespace='urn:anything'" +
        "    xmlns='http://www.w3.org/2001/XMLSchema'" +
        "    elementFormDefault='qualified'>\n" +
        "  <complexType name='simple'/>\n" +
        "</schema>";
    
    public static final String COMPLEX_SEQUENCE_SCHEMA =
        "<schema targetNamespace='urn:anything'" +
        "    xmlns='http://www.w3.org/2001/XMLSchema'" +
        "    elementFormDefault='qualified'>\n" +
        "  <complexType name='simple'>\n" +
        "    <sequence>\n" +
        "      <element name='name' type='string'/>\n" +
        "      <element name='age' type='int'/>\n" +
        "    </sequence>\n" +
        "  </complexType>\n" +
        "</schema>";
    
    public static final String COMPLEX_SEQUENCE_ATTRIBUTES_SCHEMA =
        "<schema targetNamespace='urn:anything'" +
        "    xmlns='http://www.w3.org/2001/XMLSchema'" +
        "    xmlns:tns='urn:anything'" +
        "    elementFormDefault='qualified'>\n" +
        "  <complexType name='simple'>\n" +
        "    <choice minOccurs='1' maxOccurs='3'>\n" +
        "      <element name='name' type='string'/>\n" +
        "      <element name='age' type='int'/>\n" +
        "      <element ref='tns:simple'/>\n" +
        "    </choice>\n" +
        "    <attribute name='male' use='required' type='boolean'/>\n" +
        "    <attribute name='registered' default='true' type='boolean'/>\n" +
        "  </complexType>\n" +
        "  <element name='simple' type='string'/>\n" +
        "</schema>";
        
    public static final String COMPLEX_EMBEDDED_SCHEMA =
        "<schema targetNamespace='urn:anything'" +
        "    xmlns='http://www.w3.org/2001/XMLSchema'" +
        "    elementFormDefault='qualified'>\n" +
        "  <element name='complex'>\n" +
        "    <complexType>\n" +
        "      <sequence>\n" +
        "        <element name='name' minOccurs='1' type='string'/>\n" +
        "        <element name='age' type='int'/>\n" +
        "      </sequence>\n" +
        "      <attribute name='male' use='required' type='boolean'/>\n" +
        "    </complexType>\n" +
        "  </element>\n" +
        "</schema>";
    
    public static final String COMPLEX_REFERENCED_SCHEMA =
        "<schema targetNamespace='urn:anything'" +
        "    xmlns='http://www.w3.org/2001/XMLSchema'" +
        "    xmlns:tns='urn:anything'" +
        "    elementFormDefault='qualified'>\n" +
        "  <complexType name='simple'>\n" +
        "    <sequence>\n" +
        "      <element name='name' type='string'/>\n" +
        "      <element name='age' type='int'/>\n" +
        "    </sequence>\n" +
        "    <attribute name='male' use='required' type='boolean'/>\n" +
        "    <attribute name='registered' default='true' type='boolean'/>\n" +
        "  </complexType>\n" +
        "  <element name='simple' type='tns:simple'/>\n" +
        "</schema>";
    
    private ModelBuilder m_builder;
    
    /* (non-Javadoc)
     * @see org.jibx.schema.SchemaTestBase#setUp()
     */
    protected void setUp() throws Exception {
        m_builder = new ModelBuilder();
    }

    /**
     * Find top-level naemd definition child of schema.
     *
     * @param name
     * @param schema
     * @return child
     */
    private AnnotatedBase findNamedChild(String name, SchemaElement schema) {
        List childs = schema.getTopLevelChildren();
        for (Iterator iter = childs.iterator(); iter.hasNext();) {
            AnnotatedBase child = (AnnotatedBase)iter.next();
            if (child instanceof INamed) {
                if (name.equals(((INamed)child).getName())) {
                    return child;
                }
            }
        }
        fail("Expected child '" + name + "' not found");
        return null;
    }
    
    public void testComplexEmpty() throws Exception {
        SchemaElement schema = prepareSchema(COMPLEX_EMPTY_SCHEMA);
        AnnotatedBase child = findNamedChild("simple", schema);
        TypedDefinitionStructure struct = m_builder.buildDefinitionStructure(child);
    }
    
    public void testComplexSequence() throws Exception {
        SchemaElement schema = prepareSchema(COMPLEX_SEQUENCE_SCHEMA);
    }
    
    public void testComplexSequenceAttributes() throws Exception {
        SchemaElement schema = prepareSchema(COMPLEX_SEQUENCE_ATTRIBUTES_SCHEMA);
    }
    
    public void testComplexEmbedded() throws Exception {
        SchemaElement schema = prepareSchema(COMPLEX_EMBEDDED_SCHEMA);
    }
    
    public void testComplexReferenced() throws Exception {
        SchemaElement schema = prepareSchema(COMPLEX_REFERENCED_SCHEMA);
    }
}